#ifndef LEARN_ENVIRONMENT_HPP
#define LEARN_ENVIRONMENT_HPP

#include <rviz/panel.h>
#include <ui_learn_environment.h>
#include "task_management/task_manager.hpp"
#include "ui/task_ui.hpp"

#include <QWidget>
#include <QObject>
#include <QProcess>

QT_BEGIN_NAMESPACE
/**
 * @namespace Ui
 * @brief Contains classes generated by Qt's User Interface Compiler (uic) from .ui files.
 *
 * The Ui namespace is used to encapsulate classes that are automatically generated
 * by the Qt framework from user interface definition files (.ui). These classes
 * are responsible for setting up the UI elements as defined in the .ui files.
 */
namespace Ui {
    class LearnEnvironment;
}
QT_END_NAMESPACE

/**
 * @class LearnEnvironment
 * @brief A custom RViz panel for managing the learning environment.
 *
 * The LearnEnvironment class provides a user interface for managing tasks and their execution
 * and evaluation within the learning environment.
 */
class LearnEnvironment : public rviz::Panel
{
    Q_OBJECT

public:
    /**
     * @brief Constructs a LearnEnvironment object.
     * @param parent Pointer to the parent widget.
     */
    LearnEnvironment(QWidget *parent = 0);

    /**
     * @brief Destroys the LearnEnvironment object.
     */
    ~LearnEnvironment();

    /**
     * @brief Loads user-specific settings.
     * @param config The RViz configuration object.
     */
    virtual void load(const rviz::Config &config) override;

    /**
     * @brief Saves user-specific settings.
     * @param config The RViz configuration object.
     */
    virtual void save(rviz::Config config) const override;

private:
    Ui::LearnEnvironment *ui; ///< Pointer to the UI object.
    TaskManager *taskManager; ///< Pointer to the TaskManager object.
    TaskUI *taskUI; ///< Pointer to the TaskUI object.
    QProcess *process; ///< Pointer to the QProcess object.

    /**
     * @brief Initializes the UI and the startup logic.
     */
    void initialize();
};

#endif // LEARN_ENVIRONMENT_HPP